# ReliefE: Feature Ranking via Manifold Embeddings

This repository hosts the implementation of the ReliefE idea, suitable both for _multiclass_ and _multilabel_ **feature ranking** problems.

![Scheme](images/scheme.png)

To get started with ReliefE, please consult the [documentation pages](https://reliefe.readthedocs.io/en/latest/)